package App::Greple::under::line;
use strict;
use warnings;

our $VERSION = "0.9904";

use App::Greple::under ':all';

1;

__DATA__

option default \
    -Munder \
    --use-custom-colormap \
    --place-line
